#[repr(transparent)]pub struct NSAlertStyle(pub NSUInteger);NSAlert only.Expand description
The alert styles used by the alertStyle property on instances of NSAlert.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl NSAlertStyle
impl NSAlertStyle
Sourcepub const Warning: Self
pub const Warning: Self
An alert style to be used to warn the user about a current or impending event.
This style should be used when the alert’s content is more severe than NSAlertStyleInformational but less than NSAlertStyleCritical.
This is the default alert style.
Sourcepub const Informational: Self
pub const Informational: Self
An alert style to be used to inform the user about a current or impending event.
- Note: Currently, there is no visual difference between informational and warning alerts.
Sourcepub const Critical: Self
pub const Critical: Self
An alert style to be used to inform the user about a critical event. Causes the alert’s icon to be badged with a caution icon. The critical (or “caution”) style should be used sparingly. Using it too frequently diminishes its significance. Use the symbol only when extra attention is really needed, as when confirming an action that might result in unexpected loss of data. Don’t use the symbol for tasks whose only purpose is to overwrite or remove data, such as a save or empty trash.