#[repr(transparent)]pub struct NSVisualEffectMaterial(pub NSInteger);NSVisualEffectView only.Expand description
The main material that this view displays. Materials are dynamic, and their exact look depends on the view’s effectiveAppearance, blendingMode, state, emphasized, and possibly other factors.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl NSVisualEffectMaterial
impl NSVisualEffectMaterial
Sourcepub const Selection: Self
pub const Selection: Self
The material used in some table views, menus, etc., to indicate selection.
Sourcepub const HeaderView: Self
pub const HeaderView: Self
The material used in various in-line header or footer views (e.g., by NSTableView).
Sourcepub const WindowBackground: Self
pub const WindowBackground: Self
The material used by opaque window backgrounds.
Sourcepub const HUDWindow: Self
pub const HUDWindow: Self
The material used as the background of heads-up display (HUD) windows.
Sourcepub const FullScreenUI: Self
pub const FullScreenUI: Self
The material used as the background of full-screen modal UI.
Sourcepub const ContentBackground: Self
pub const ContentBackground: Self
The material used as the opaque background of content (e.g., by NSScrollView, NSTableView, NSCollectionView, etc.).
Sourcepub const UnderWindowBackground: Self
pub const UnderWindowBackground: Self
The material used under window backgrounds.
Sourcepub const UnderPageBackground: Self
pub const UnderPageBackground: Self
The material used as the background behind document pages.
Sourcepub const AppearanceBased: Self
👎Deprecated: Use a specific semantic material instead.
pub const AppearanceBased: Self
Use a specific semantic material instead.
A default material appropriate for the view’s effectiveAppearance. You should instead choose an appropriate semantic material.
Sourcepub const Light: Self
👎Deprecated: Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
pub const Light: Self
Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
A default material appropriate for the view’s effectiveAppearance. You should instead choose an appropriate semantic material.
Sourcepub const Dark: Self
👎Deprecated: Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
pub const Dark: Self
Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
A default material appropriate for the view’s effectiveAppearance. You should instead choose an appropriate semantic material.
Sourcepub const MediumLight: Self
👎Deprecated: Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
pub const MediumLight: Self
Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
A default material appropriate for the view’s effectiveAppearance. You should instead choose an appropriate semantic material.
Sourcepub const UltraDark: Self
👎Deprecated: Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
pub const UltraDark: Self
Use a semantic material instead. To force the appearance of a view hierarchy, set the appearance property to an appropriate NSAppearance value.
A default material appropriate for the view’s effectiveAppearance. You should instead choose an appropriate semantic material.