pub unsafe trait NSAccessibilityElementLoading: NSObjectProtocol {
// Provided methods
unsafe fn accessibilityElementWithToken(
&self,
token: &NSAccessibilityLoadingToken,
) -> Option<Retained<ProtocolObject<dyn NSAccessibilityElementProtocol>>>
where Self: Sized + Message { ... }
unsafe fn accessibilityRangeInTargetElementWithToken(
&self,
token: &NSAccessibilityLoadingToken,
) -> NSRange
where Self: Sized + Message { ... }
}Available on crate feature
NSAccessibilityProtocols only.Expand description
Provided Methods
Sourceunsafe fn accessibilityElementWithToken(
&self,
token: &NSAccessibilityLoadingToken,
) -> Option<Retained<ProtocolObject<dyn NSAccessibilityElementProtocol>>>
Available on crate feature NSAccessibilityConstants only.
unsafe fn accessibilityElementWithToken( &self, token: &NSAccessibilityLoadingToken, ) -> Option<Retained<ProtocolObject<dyn NSAccessibilityElementProtocol>>>
NSAccessibilityConstants only.Loads the target element with the given load token.
Returns: An element that will be messaged for other accessibility properties. Assistive technologies may try to set accessibility focus on the returned element.
Safety
token should be of the correct type.
Sourceunsafe fn accessibilityRangeInTargetElementWithToken(
&self,
token: &NSAccessibilityLoadingToken,
) -> NSRange
Available on crate feature NSAccessibilityConstants only.
unsafe fn accessibilityRangeInTargetElementWithToken( &self, token: &NSAccessibilityLoadingToken, ) -> NSRange
NSAccessibilityConstants only.For text-based elements returned from accessibilityElementWithToken, such as an NSTextView, the range specifies an area of interest. Assistive technologies will try to bring focus to the specified text range.
Either do not implement this method or return NSNotFound for the location if there is no range of interest for a given load token.
Safety
token should be of the correct type.