NSAlertDelegate

Trait NSAlertDelegate 

pub unsafe trait NSAlertDelegate: NSObjectProtocol + MainThreadOnly {
    // Provided method
    fn alertShowHelp(&self, alert: &NSAlert) -> bool
       where Self: Sized + Message { ... }
}
Available on crate feature NSAlert only.
A set of optional methods implemented by the delegate of an NSAlert object to respond to a user’s request for help.

See also Apple’s documentation

Provided Methods

fn alertShowHelp(&self, alert: &NSAlert) -> bool
where Self: Sized + Message,

Sent to the delegate when the user clicks the alert’s help button. The delegate causes help to be displayed for an alert, directly or indirectly.

  • Returns: YES when the delegate displayed help directly, NO otherwise. When NO and the alert has a help anchor (helpAnchor), the application’s help manager displays help using the help anchor.
  • Discussion: The delegate implements this method only to override the help-anchor lookup behavior.