pub unsafe trait NSCloudSharingServiceDelegate: NSSharingServiceDelegate {
// Provided methods
unsafe fn sharingService_didCompleteForItems_error(
&self,
sharing_service: &NSSharingService,
items: &NSArray,
error: Option<&NSError>,
)
where Self: Sized + Message { ... }
fn optionsForSharingService_shareProvider(
&self,
cloud_kit_sharing_service: &NSSharingService,
provider: &NSItemProvider,
) -> NSCloudKitSharingServiceOptions
where Self: Sized + Message { ... }
fn sharingService_didSaveShare(
&self,
sharing_service: &NSSharingService,
share: &CKShare,
)
where Self: Sized + Message { ... }
fn sharingService_didStopSharing(
&self,
sharing_service: &NSSharingService,
share: &CKShare,
)
where Self: Sized + Message { ... }
}NSSharingService only.Expand description
Provided Methods
Sourceunsafe fn sharingService_didCompleteForItems_error(
&self,
sharing_service: &NSSharingService,
items: &NSArray,
error: Option<&NSError>,
)
unsafe fn sharingService_didCompleteForItems_error( &self, sharing_service: &NSSharingService, items: &NSArray, error: Option<&NSError>, )
When an NSSharingServiceNameCloudSharing sharing service is dismissed it will invoke this method on the delegate, with an error if there was any. If the delegate implements this method, NSSharingServiceNameCloudSharing will not send -sharingService:didFailToShareItems:error: or -sharingService:didShareItems:.
Safety
items generic should be of the correct type.
The options returned by this method describe how the user is allowed to configure the share: whether the share is public or private, and whether participants have read-only or read/write permissions. If this method is not implemented, NSCloudKitSharingServiceStandard is assumed.
Available on Apple and crate feature objc2-cloud-kit only.
objc2-cloud-kit only.When an NSSharingServiceNameCloudSharing sharing service successfully saves modifications to the CKShare, it will invoke this method on the delegate with the last-known state of the CKShare on the server.
Sourcefn sharingService_didStopSharing(
&self,
sharing_service: &NSSharingService,
share: &CKShare,
)
Available on Apple and crate feature objc2-cloud-kit only.
fn sharingService_didStopSharing( &self, sharing_service: &NSSharingService, share: &CKShare, )
objc2-cloud-kit only.When an NSSharingServiceNameCloudSharing sharing service stops sharing it will delete the CKShare from the server, then invoke this method on the delegate with the last-known state of the CKShare.