NSPreviewRepresentableActivityItem

Trait NSPreviewRepresentableActivityItem 

pub unsafe trait NSPreviewRepresentableActivityItem: NSObjectProtocol {
    // Provided methods
    fn item(&self) -> Retained<AnyObject>
       where Self: Sized + Message { ... }
    fn title(&self) -> Option<Retained<NSString>>
       where Self: Sized + Message { ... }
    fn imageProvider(&self) -> Option<Retained<NSItemProvider>>
       where Self: Sized + Message { ... }
    fn iconProvider(&self) -> Option<Retained<NSItemProvider>>
       where Self: Sized + Message { ... }
}
Available on crate feature NSPreviewRepresentingActivityItem only.
Provided Methods

fn item(&self) -> Retained<AnyObject>
where Self: Sized + Message,

The item to be shared

fn title(&self) -> Option<Retained<NSString>>
where Self: Sized + Message,

A string representing the name or title of the item to be shared

fn imageProvider(&self) -> Option<Retained<NSItemProvider>>
where Self: Sized + Message,

Provides an image appropriate to represent the item.

This image typically is a full-size representation of the content being shared. For instance, if sharing a link to a webpage, this might be the hero image on that webpage.

fn iconProvider(&self) -> Option<Retained<NSItemProvider>>
where Self: Sized + Message,

Provides an icon appropriate to represent the item.

This icon typically is a thumbnail-sized representation of the source of the content. For instance, if sharing a link to a webpage, this might be an icon representing the website overall.