NSTextAttachmentCellProtocol

Trait NSTextAttachmentCellProtocol 

pub unsafe trait NSTextAttachmentCellProtocol: NSObjectProtocol {
Show 13 methods // Provided methods fn drawWithFrame_inView( &self, cell_frame: NSRect, control_view: Option<&NSView>, mtm: MainThreadMarker, ) where Self: Sized + Message { ... } fn wantsToTrackMouse(&self, mtm: MainThreadMarker) -> bool where Self: Sized + Message { ... } fn highlight_withFrame_inView( &self, flag: bool, cell_frame: NSRect, control_view: Option<&NSView>, mtm: MainThreadMarker, ) where Self: Sized + Message { ... } fn trackMouse_inRect_ofView_untilMouseUp( &self, the_event: &NSEvent, cell_frame: NSRect, control_view: Option<&NSView>, flag: bool, mtm: MainThreadMarker, ) -> bool where Self: Sized + Message { ... } fn cellSize(&self) -> NSSize where Self: Sized + Message { ... } fn cellBaselineOffset(&self) -> NSPoint where Self: Sized + Message { ... } unsafe fn attachment(&self) -> Option<Retained<NSTextAttachment>> where Self: Sized + Message { ... } unsafe fn setAttachment(&self, attachment: Option<&NSTextAttachment>) where Self: Sized + Message { ... } fn drawWithFrame_inView_characterIndex( &self, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, mtm: MainThreadMarker, ) where Self: Sized + Message { ... } fn drawWithFrame_inView_characterIndex_layoutManager( &self, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, layout_manager: &NSLayoutManager, mtm: MainThreadMarker, ) where Self: Sized + Message { ... } fn wantsToTrackMouseForEvent_inRect_ofView_atCharacterIndex( &self, the_event: &NSEvent, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, mtm: MainThreadMarker, ) -> bool where Self: Sized + Message { ... } fn trackMouse_inRect_ofView_atCharacterIndex_untilMouseUp( &self, the_event: &NSEvent, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, flag: bool, mtm: MainThreadMarker, ) -> bool where Self: Sized + Message { ... } fn cellFrameForTextContainer_proposedLineFragment_glyphPosition_characterIndex( &self, text_container: &NSTextContainer, line_frag: NSRect, position: NSPoint, char_index: NSUInteger, ) -> NSRect where Self: Sized + Message { ... }
}
Available on crate feature NSTextAttachmentCell only.
Provided Methods

fn drawWithFrame_inView( &self, cell_frame: NSRect, control_view: Option<&NSView>, mtm: MainThreadMarker, )
where Self: Sized + Message,

Available on crate features NSResponder and NSView only.
fn wantsToTrackMouse(&self, mtm: MainThreadMarker) -> bool
where Self: Sized + Message,

fn highlight_withFrame_inView( &self, flag: bool, cell_frame: NSRect, control_view: Option<&NSView>, mtm: MainThreadMarker, )
where Self: Sized + Message,

Available on crate features NSResponder and NSView only.
fn trackMouse_inRect_ofView_untilMouseUp( &self, the_event: &NSEvent, cell_frame: NSRect, control_view: Option<&NSView>, flag: bool, mtm: MainThreadMarker, ) -> bool
where Self: Sized + Message,

Available on crate features NSEvent and NSResponder and NSView only.
fn cellSize(&self) -> NSSize
where Self: Sized + Message,

fn cellBaselineOffset(&self) -> NSPoint
where Self: Sized + Message,

unsafe fn attachment(&self) -> Option<Retained<NSTextAttachment>>
where Self: Sized + Message,

Available on crate feature NSTextAttachment only.
Safety

This is not retained internally, you must ensure the object is still alive.

unsafe fn setAttachment(&self, attachment: Option<&NSTextAttachment>)
where Self: Sized + Message,

Available on crate feature NSTextAttachment only.

Setter for attachment.

Safety

This is unretained, you must ensure the object is kept alive while in use.

fn drawWithFrame_inView_characterIndex( &self, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, mtm: MainThreadMarker, )
where Self: Sized + Message,

Available on crate features NSResponder and NSView only.
fn drawWithFrame_inView_characterIndex_layoutManager( &self, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, layout_manager: &NSLayoutManager, mtm: MainThreadMarker, )
where Self: Sized + Message,

Available on crate features NSLayoutManager and NSResponder and NSView only.
fn wantsToTrackMouseForEvent_inRect_ofView_atCharacterIndex( &self, the_event: &NSEvent, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, mtm: MainThreadMarker, ) -> bool
where Self: Sized + Message,

Available on crate features NSEvent and NSResponder and NSView only.
fn trackMouse_inRect_ofView_atCharacterIndex_untilMouseUp( &self, the_event: &NSEvent, cell_frame: NSRect, control_view: Option<&NSView>, char_index: NSUInteger, flag: bool, mtm: MainThreadMarker, ) -> bool
where Self: Sized + Message,

Available on crate features NSEvent and NSResponder and NSView only.
fn cellFrameForTextContainer_proposedLineFragment_glyphPosition_characterIndex( &self, text_container: &NSTextContainer, line_frag: NSRect, position: NSPoint, char_index: NSUInteger, ) -> NSRect
where Self: Sized + Message,

Available on crate feature NSTextContainer only.