pub unsafe trait NSAlertDelegate: NSObjectProtocol + MainThreadOnly {
// Provided method
fn alertShowHelp(&self, alert: &NSAlert) -> bool
where Self: Sized + Message { ... }
}Available on crate feature
NSAlert only.Expand description
A set of optional methods implemented by the delegate of an NSAlert object to respond to a user’s request for help.
See also Apple’s documentation
Provided Methods
Sourcefn alertShowHelp(&self, alert: &NSAlert) -> bool
fn alertShowHelp(&self, alert: &NSAlert) -> bool
Sent to the delegate when the user clicks the alert’s help button. The delegate causes help to be displayed for an alert, directly or indirectly.
- Returns:
YESwhen the delegate displayed help directly,NOotherwise. WhenNOand the alert has a help anchor (helpAnchor), the application’s help manager displays help using the help anchor. - Discussion: The delegate implements this method only to override the help-anchor lookup behavior.