pub unsafe trait NSCloudSharingValidation: NSObjectProtocol + MainThreadOnly {
// Provided method
fn cloudShareForUserInterfaceItem(
&self,
item: &ProtocolObject<dyn NSValidatedUserInterfaceItem>,
) -> Option<Retained<CKShare>>
where Self: Sized + Message { ... }
}Available on crate feature
NSToolbarItem only.Expand description
Provided Methods
Available on Apple and crate feature NSUserInterfaceValidation and crate feature objc2-cloud-kit only.
NSUserInterfaceValidation and crate feature objc2-cloud-kit only.NSToolbarItems created with NSToolbarCloudSharingItemIdentifier use this method for further validation after sending -validateToolbarItem: or -validateUserInterfaceItem:.
The validator for the item’s action should return the current CKShare corresponding to the selected item, if any.
The state of the item will be changed reflect the state of the CKShare.